/*
 * Copyright 2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.portals.bridges.jsf;

import javax.faces.component.NamingContainer;
import javax.faces.component.UIViewRoot;
import javax.faces.context.FacesContext;

/**
 * A portlet view root that implements a naming container to creates unique 
 * client ids.
 * @author Matthew Bruzek
 */
public class PortletUIViewRoot extends UIViewRoot implements NamingContainer
{
  /** A portlet view id constant to prepend to the namespace. */
  public static final String VIEW_PREFIX = "view";
  
  /** The default constructor calls the UIViewRoot default constructor.  */
  public PortletUIViewRoot()
  {
    super();
  }

  /**
   * The convenience constructor creates a PortletUIViewRoot from a UIViewRoot.
   * @param viewRoot The UIViewRoot to use when creating this object.
   */
  public PortletUIViewRoot( UIViewRoot viewRoot )
  {
    setLocale( viewRoot.getLocale() );
    setRenderKitId( viewRoot.getRenderKitId() );
    setViewId( viewRoot.getViewId() );
  }

  /**
   * Return a string which can be used as output to the response which uniquely 
   * identifies a component within the current view.
   * @param context The FacesContext object for the current request.
   */
  public String getClientId( FacesContext context )
  {
    if ( context == null )
      throw new NullPointerException( "context can not be null." );
    
    String nameSpace = context.getExternalContext().encodeNamespace( "" );
    return VIEW_PREFIX + nameSpace;
  }
}
